import { hasOnlyKeys, hasProperty } from "./validation";
import type { Id } from "./server/Id";
import type { State } from "./State";

export interface GameData {
	isStarted: boolean;
	players: Id[];
	state: State;
}

export function isGameData(target: unknown): target is GameData {
	if (!hasProperty(target, "isStarted", "boolean")) {
		return false;
	}

	if (!hasProperty(target, "players", "string[]")) {
		return false;
	}

	// the user cannot update this property, they have to send it as it is, so if we
	// receive something that isn't a correctly formed state, that will get rejected
	// anyway (since it won't match what we already have).
	if (!hasProperty(target, "state", "object")) {
		return false;
	}

	return hasOnlyKeys(target, ["players", "isStarted", "state"]);
}
