import { hasProperty } from "$lib/validation";

export interface Listing<T> {
	id: string;
	createdAt: string;
	modifiedAt: string | null;
	deleted: boolean;
	data: T;
}

export function isListing<T>(
	target: unknown,
	dataGuard?: (target: unknown) => target is T
): target is Listing<T> {
	if (!hasProperty(target, "id", "string")) return false;
	if (!hasProperty(target, "createdAt", "string")) return false;

	if (!hasProperty(target, "modifiedAt", "null")) {
		if (!hasProperty(target, "modifiedAt", "string")) return false;
	}

	if (!hasProperty(target, "deleted", "boolean")) return false;
	if (!hasProperty(target, "data", "object")) return false;

	return dataGuard?.((target as any)["data"]) ?? true;
}
