import { describe, it } from "node:test";
import { GameData, isGameData } from "../../GameData";
import { equal, ok } from "node:assert/strict";

describe("GameData", () => {
	describe("isGameData", () => {
		it("rejects a malformed object", () => {
			let data: unknown = {
				players: ["id", 3],
				isStarted: false,
				state: {},
			};
			equal(isGameData(data), false);

			data = {
				players: ["id"],
				isStarted: null,
				state: {},
			};
			equal(isGameData(data), false);

			data = {
				players: ["id"],
				isStarted: false,
			};
			equal(isGameData(data), false);
		});

		it("rejects an object with extra properties", () => {
			const data: GameData & { extra: boolean } = {
				players: ["id"],
				isStarted: false,
				state: {},
				extra: true,
			};

			equal(isGameData(data), false);
		});

		it("should accept a proper GameData object", () => {
			const data: GameData = {
				players: ["id"],
				state: {},
				isStarted: false,
			};

			ok(isGameData(data));
		});
	});
});
