import { describe, it } from "node:test";
import { createNewListing, updateListing } from "../modifyListing";
import { Game } from "../../Game";
import { deepEqual, equal, ok } from "node:assert/strict";

describe("Listing", () => {
	describe("createNewListing", () => {
		it("should create a new Listing with the provided data, and a new UUID", () => {
			const game = new Game();
			const listing = createNewListing(game);

			ok(listing.data instanceof Game);
			ok(listing.createdAt instanceof Date);
			ok(listing.modifiedAt === null);
			ok(!listing.deleted);
			equal(typeof listing.id, "string");
		});
	});

	describe("updateListing", () => {
		it("should return a new listing with updated data and a modified date", () => {
			const game = new Game();
			const update = new Game();
			update.isStarted = !game.isStarted;

			const listing = createNewListing(game);
			const updatedListing = updateListing(listing, update);

			deepEqual(updatedListing.data, update);
			ok(updatedListing.modifiedAt instanceof Date);
		});
	});
});
